%define base_name i3

Name:           i3-gaps
Version:        4.20.1
Release:        1%{?dist}
Summary:        i3 with more features
License:        BSD
URL:            https://github.com/Airblader/i3
Source0:        %{url}/archive/%{version}.tar.gz#/i3-%{version}.tar.gz
Source1:        i3-logo.svg

BuildRequires:  gcc
BuildRequires:  meson
BuildRequires:  ninja-build
BuildRequires:  asciidoc
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libev-devel
BuildRequires:  libX11-devel
BuildRequires:  libxcb-devel
BuildRequires:  libXcursor-devel
BuildRequires:  libxkbcommon-x11-devel
BuildRequires:  libxkbfile-devel
BuildRequires:  pango-devel
BuildRequires:  pcre-devel
BuildRequires:  perl(Getopt::Long)
BuildRequires:  perl(Data::Dumper::Names)
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  startup-notification-devel
BuildRequires:  xcb-proto
BuildRequires:  xcb-util-cursor-devel
BuildRequires:  xcb-util-devel
BuildRequires:  xcb-util-keysyms-devel
BuildRequires:  xcb-util-wm-devel
BuildRequires:  xmlto
BuildRequires:  yajl-devel
BuildRequires:  git
BuildRequires:  pkgconfig(xcb-xrm)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(cairo-xcb)

Requires:       perl-libs
Requires:       xorg-x11-fonts-misc


Conflicts:      otherproviders(i3)
Provides:       i3 = %{version}


%description
Key features of i3 are correct implementation of XrandR, horizontal and vertical
columns (think of a table) in tiling. Also, special focus is on writing clean,
readable and well documented code. i3 uses xcb for asynchronous communication
with X11, and has several measures to be very fast.

Please be aware that i3 is primarily targeted at advanced users and developers.


%package        doc
Summary:        Documentation for %{name}
BuildRequires:  doxygen
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description    doc
Asciidoc and doxygen generated documentations for %{name}.

%prep
%autosetup -n i3-%{version}

# Drop /usr/bin/env lines in those which will be installed to %%_bindir.
find . -maxdepth 1 -type f -name "i3*" -exec sed -i -e '1s;^#!/usr/bin/env perl;#!/usr/bin/perl;' {} + -print

# 1. Drop dwarf-2, -g3 in CFLAGS recommended by gcc maintainer. Since upstream
# uses -pipe and -g only, we can safely ignore these, but ldflags needs
# override still.
# 2. Preserve the timestamps.
#sed -i -e 's|LDFLAGS ?=|override LDFLAGS +=|g' #       -e 's|INSTALL=.*|INSTALL=install -p|g' #       common.mk

%build
%meson -Ddocs=true \
       -Dmans=true
%meson_build

doxygen pseudo-doc.doxygen
mv pseudo-doc/html pseudo-doc/doxygen

%install
%meson_install

mkdir -p %{buildroot}%{_mandir}/man1/
install -Dpm0644 %{_vpath_builddir}/*.1         %{buildroot}%{_mandir}/man1/

mkdir -p %{buildroot}%{_datadir}/pixmaps/
install -Dpm0644 %{SOURCE1}         %{buildroot}%{_datadir}/pixmaps/

#check
#ifnarch s390 s390x
## TODO: with xorg dummy to test the package.
##cd testcases/ && ./complete-run.pl -p 1
#endif

%files
%doc RELEASE-NOTES-%{version}
%license LICENSE
%{_bindir}/%{base_name}*
%{_includedir}/%{base_name}/
%dir %{_sysconfdir}/%{base_name}/
%config(noreplace) %{_sysconfdir}/%{base_name}/config
%config(noreplace) %{_sysconfdir}/%{base_name}/config.keycodes
%{_datadir}/xsessions/%{base_name}.desktop
%{_datadir}/xsessions/%{base_name}-with-shmlog.desktop
%{_mandir}/man*/%{base_name}*
%{_datadir}/pixmaps/%{base_name}-logo.svg
%{_datadir}/applications/%{base_name}.desktop
%exclude %{_docdir}/%{base_name}/

%files doc
%doc docs/*.{html,png} pseudo-doc/doxygen/

%changelog
* Sat Mar 26 2022 Jan Drögehoff <sentrycraft123@gmail.com> - 4.20.1-1
- Update to 4.20.1

* Thu Feb 18 2021 Jan Drögehoff <sentrycraft123@gmail.com> - 4.19.1-1
- Update to Version 4.19.1

* Mon Nov 02 2020 Jan Drögehoff <sentrycraft123@gmail.com> - 4.18.3-2
- Change perl dependency to be more explicit

* Sun Nov 01 2020 Jan Drögehoff <sentrycraft123@gmail.com> - 4.18.3-1
- Update to Version 4.18.3

* Wed Apr 29 2020 Jan Drögehoff <sentrycraft123@gmail.com> - 4.18.1-1
- Bump to new version

* Wed Apr 29 2020 Jan Drögehoff <sentrycraft123@gmail.com> - 4.17.1-2
- Rebuilt for Fedora 32

* Fri Dec 06 2019 Greg Wildman <greg@techno.co.za> - 4.17.1-1
- Update to new version

* Mon May 13 2019 Greg Wildman <greg@techno.co.za> - 4.16.1-1
- Update to new version

* Thu Nov 15 2018 Greg Wildman <greg@techno.co.za> - 4.16-1
- Update to new version

* Sun Oct 08 2017 Greg Wildman <greg@techno.co.za> - 4.14.1-2
- Update to new version

* Sun Sep 24 2017 Greg Wildman <greg@techno.co.za> - 4.14-1
- Update to new version

* Thu Nov 10 2016 Yaroslav Sapozhnyk <yaroslav.sapozhnik@gmail.com> - 4.13-1
- Updating to version 4.13; Added dependency for cairo/pango and xcb-xrm


